@@ -255,12 +255,12 @@ public class Concat extends Task implements ResourceCollection {
          */
         public int read() throws IOException {
             if (needAddSeparator) {
-                int ret = eolString.charAt(lastPos++);
                 if (lastPos >= eolString.length()) {
                     lastPos = 0;
                     needAddSeparator = false;
+                } else {
+                    return eolString.charAt(lastPos++);
                 }
-                return ret;
             }
             while (getReader() != null) {
                 int ch = getReader().read();
@@ -268,7 +268,8 @@ public class Concat extends Task implements ResourceCollection {
                     nextReader();
                     if (isFixLastLine() && isMissingEndOfLine()) {
                         needAddSeparator = true;
-                        lastPos = 0;
+                        lastPos = 1;
+                        return eolString.charAt(0);
                     }
                 } else {
                     addLastChar((char) ch);
@@ -474,9 +475,9 @@ public class Concat extends Task implements ResourceCollection {
     private boolean forceOverwrite = true;
     /** overwrite read-only files */
     private boolean force = false;
-    /** String to place at the start of the concatented stream */
+    /** String to place at the start of the concatenated stream */
     private TextElement footer;
-    /** String to place at the end of the concatented stream */
+    /** String to place at the end of the concatenated stream */
     private TextElement header;
     /** add missing line.separator to files **/
     private boolean fixLastLine = false;
@@ -812,7 +813,7 @@ public class Concat extends Task implements ResourceCollection {
 
     /**
      * Implement ResourceCollection.
-     * @return Iterator<Resource>.
+     * @return Iterator&lt;Resource&gt;.
      */
     public Iterator<Resource> iterator() {
         validate();
