@@ -29,6 +29,7 @@ import java.net.HttpURLConnection;
 import java.net.URL;
 import java.net.URLConnection;
 import java.util.Date;
+import java.util.zip.GZIPInputStream;
 
 import org.apache.tools.ant.BuildException;
 import org.apache.tools.ant.MagicNames;
@@ -68,10 +69,12 @@ public class Get extends Task {
     private static final String HTTPS = "https";
 
     private static final String DEFAULT_AGENT_PREFIX = "Apache Ant";
+    private static final String GZIP_CONTENT_ENCODING = "gzip";
 
     private Resources sources = new Resources();
     private File destination; // required
     private boolean verbose = false;
+    private boolean quiet = false;
     private boolean useTimestamp = false; //off by default
     private boolean ignoreErrors = false;
     private String uname = null;
@@ -251,6 +254,13 @@ public class Get extends Task {
         return getThread.wasSuccessful();
     }
 
+    @Override
+    public void log(String msg, int msgLevel) {
+        if (!quiet || msgLevel >= Project.MSG_ERR) {
+            super.log(msg, msgLevel);
+        }
+    }
+
     /**
      * Check the attributes.
      */
@@ -329,6 +339,16 @@ public class Get extends Task {
         verbose = v;
     }
 
+    /**
+     * If true, set default log level to Project.MSG_ERR.
+     *
+     * @param v if "true" then be quiet
+     * @since Ant 1.9.4
+     */
+    public void setQuiet(boolean v){
+        this.quiet = v;
+    }
+
     /**
      * If true, log errors but do not treat as fatal.
      *
@@ -679,6 +699,8 @@ public class Get extends Task {
                         + encoding);
             }
 
+            connection.setRequestProperty("Accept-Encoding", GZIP_CONTENT_ENCODING);
+
             if (connection instanceof HttpURLConnection) {
                 ((HttpURLConnection) connection)
                         .setInstanceFollowRedirects(false);
@@ -767,6 +789,10 @@ public class Get extends Task {
                         getLocation());
             }
 
+            if (GZIP_CONTENT_ENCODING.equals(connection.getContentEncoding())) {
+            	is = new GZIPInputStream(is);
+            }
+
             os = new FileOutputStream(dest);
             progress.beginDownload();
             boolean finished = false;
